@@ -31,15 +31,15 @@
 #include <QCoreApplication>
 #include <QElapsedTimer>
 
-CompletionStorage* CompletionStorage::_instance = 0;
+CompletionStorage* CompletionStorage::_instance = nullptr;
 void CompletionStorage::cleanupCompletionStorage()
 {
-    delete CompletionStorage::_instance; CompletionStorage::_instance = 0;
+    delete CompletionStorage::_instance; CompletionStorage::_instance = nullptr;
 }
 
 CompletionStorage* CompletionStorage::instance()
 {
-    if (_instance == 0) {
+    if (_instance == nullptr) {
         _instance = new CompletionStorage();
         qAddPostRoutine(CompletionStorage::cleanupCompletionStorage);
     }
@@ -66,7 +66,7 @@ void CompletionStorage::scanCatalog(Catalog* catalog)
         QString string = catalog->targetWithTags(pos).string;
         string.remove(accel);
 
-        const QStringList& words = string.toLower().split(rxSplit, QString::SkipEmptyParts);
+        const QStringList& words = string.toLower().split(rxSplit, Qt::SkipEmptyParts);
         foreach (const QString& word, words) {
             if (word.length() < wordCompletionLength)
                 continue;
