@@ -98,7 +98,7 @@ static void doSplit(QString& cleanEn,
         cleanEn.replace(rxClean1, QStringLiteral(" "));
     cleanEn.remove(accel);
 
-    words = cleanEn.toLower().split(rxSplit, QString::SkipEmptyParts);
+    words = cleanEn.toLower().split(rxSplit, Qt::SkipEmptyParts);
     if (words.size() > 4) {
         int i = 0;
         for (; i < words.size(); ++i) {
@@ -1187,7 +1187,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
             idsForWord.clear();
             queryWords.exec(queryString.arg(words.at(o)));
             if (Q_UNLIKELY(!queryWords.exec(queryString.arg(words.at(o)))))
-                qCWarning(LOKALIZE_LOG) << "select error: " << queryWords.lastError().text() << endl;
+                qCWarning(LOKALIZE_LOG) << "select error: " << queryWords.lastError().text() << Qt::endl;
 
             if (queryWords.next()) {
                 QByteArray arr(queryWords.value(0).toByteArray());
@@ -1197,7 +1197,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                 int p = ids.size();
                 idsForWord.reserve(p);
                 while (--p >= 0)
-                    idsForWord.append(ids.at(p).toLongLong(/*bool ok*/0, 36));
+                    idsForWord.append(ids.at(p).toLongLong(/*bool ok*/nullptr, 36));
             } else {
                 queryWords.clear();
                 continue;
@@ -1221,7 +1221,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
     QString sourceClean(m_source.string);
     sourceClean.remove(c.accel);
     //split m_english for use in wordDiff later--all words are needed so we cant use list we already have
-    QStringList englishList(sourceClean.toLower().split(rxSplit, QString::SkipEmptyParts));
+    QStringList englishList(sourceClean.toLower().split(rxSplit, Qt::SkipEmptyParts));
     static QRegExp delPart(QStringLiteral("<KBABELDEL>*</KBABELDEL>"), Qt::CaseSensitive, QRegExp::Wildcard);
     static QRegExp addPart(QStringLiteral("<KBABELADD>*</KBABELADD>"), Qt::CaseSensitive, QRegExp::Wildcard);
     delPart.setMinimal(true);
@@ -1266,7 +1266,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                         qCWarning(LOKALIZE_LOG) << "problem:" << queryFetch.value(3).toByteArray().size() << queryFetch.value(3).toByteArray();
                 }
                 //e.target=queryFetch.value(2).toString();
-                //QStringList e_ctxt=queryFetch.value(3).toString().split('\b',QString::SkipEmptyParts);
+                //QStringList e_ctxt=queryFetch.value(3).toString().split('\b',Qt::SkipEmptyParts);
                 //e.date=queryFetch.value(4).toString();
                 e.markupExpr = c.markup;
                 e.accelExpr = c.accel;
@@ -1277,7 +1277,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                 QString str = e.source.string;
                 str.remove(c.accel);
 
-                QStringList englishSuggList(str.toLower().split(rxSplit, QString::SkipEmptyParts));
+                QStringList englishSuggList(str.toLower().split(rxSplit, Qt::SkipEmptyParts));
                 if (englishSuggList.size() > 10 * englishList.size())
                     continue;
                 //sugg is 'old' --translator has to adapt its translation to 'new'--current
@@ -1378,7 +1378,7 @@ bool SelectJob::doSelect(QSqlDatabase& db,
                     e.target = CatalogString(makeAcceledString(queryRest.value(4).toString(), c.accel, queryRest.value(5)),
                                              queryRest.value(6).toByteArray());
 
-                    QStringList matchData = queryRest.value(2).toString().split(TM_DELIMITER, QString::KeepEmptyParts); //context|plural
+                    QStringList matchData = queryRest.value(2).toString().split(TM_DELIMITER, Qt::KeepEmptyParts); //context|plural
                     e.file = queryRest.value(7).toString();
                     if (e.target.isEmpty())
                         continue;
@@ -1544,7 +1544,7 @@ void ScanJob::run()
     TMConfig c = getConfig(db, true);
     QRegExp rxClean1(c.markup); rxClean1.setMinimal(true);
 
-    Catalog catalog(0);
+    Catalog catalog(nullptr);
     if (Q_LIKELY(catalog.loadFromUrl(m_filePath, QString(), &m_size, /*no auto save*/true) == 0)) {
         if (c.targetLangCode != catalog.targetLangCode()) {
             qCWarning(LOKALIZE_LOG) << "not indexing file because target languages don't match:" << c.targetLangCode << "in TM vs" << catalog.targetLangCode() << "in file";
@@ -2114,7 +2114,7 @@ void ExportTmxJob::run()
 
 ExecQueryJob::ExecQueryJob(const QString& queryString, const QString& dbName, QMutex *dbOperation)
     : QObject(), QRunnable()
-    , query(0)
+    , query(nullptr)
     , m_dbName(dbName)
     , m_query(queryString)
     , m_dbOperationMutex(dbOperation)
